diff --git a/src/app/mainwindow.h b/src/app/mainwindow.h
index 5fe2a1c1e..87925ea63 100644
--- a/src/app/mainwindow.h
+++ b/src/app/mainwindow.h
@@ -72,7 +72,7 @@ public slots:
bool SaveAs();
bool Save();
void Open();
- void Options();
+ void Preferences();
void NewPattern();
void currentDrawChanged( int index );
diff --git a/src/app/mainwindow.ui b/src/app/mainwindow.ui
index 24e0daea6..3ba2bcbfe 100644
--- a/src/app/mainwindow.ui
+++ b/src/app/mainwindow.ui
@@ -47,7 +47,7 @@
0
0
- 144
+ 150
150
@@ -302,7 +302,7 @@
0
0
- 100
+ 150
58
@@ -378,7 +378,7 @@
0
0
- 100
+ 150
104
@@ -579,7 +579,7 @@
0
0
- 100
+ 150
58
@@ -676,6 +676,8 @@
+
+
diff --git a/src/app/mainwindow.cpp b/src/app/mainwindow.cpp
index 3ef5a7360..652abf98d 100644
--- a/src/app/mainwindow.cpp
+++ b/src/app/mainwindow.cpp
@@ -1292,9 +1292,9 @@ void MainWindow::Open()
//---------------------------------------------------------------------------------------------------------------------
/**
* @brief Options config dialog.
*/
-void MainWindow::Options()
+void MainWindow::Preferences()
{
ConfigDialog dlg(this);
if (dlg.exec() == QDialog::Accepted)
@@ -1701,11 +1701,11 @@ void MainWindow::CreateMenus()
{
for (int i = 0; i < MaxRecentFiles; ++i)
{
- ui->menuFile->insertAction(ui->actionExit, recentFileActs[i]);
+ ui->menuFile->insertAction(ui->actionPreferences, recentFileActs[i]);
}
separatorAct = new QAction(this);
separatorAct->setSeparator(true);
- ui->menuFile->insertAction(ui->actionExit, separatorAct);
+ ui->menuFile->insertAction(ui->actionPreferences, separatorAct);
UpdateRecentFileActions();
}
@@ -1727,7 +1727,7 @@ void MainWindow::CreateActions()
connect(ui->actionAbout_Qt, &QAction::triggered, this, &MainWindow::AboutQt);
connect(ui->actionAbout_Valentina, &QAction::triggered, this, &MainWindow::About);
connect(ui->actionExit, &QAction::triggered, this, &MainWindow::close);
- connect(ui->actionOptions, &QAction::triggered, this, &MainWindow::Options);
+ connect(ui->actionPreferences, &QAction::triggered, this, &MainWindow::Preferences);
connect(ui->actionPattern_properties, &QAction::triggered, this, &MainWindow::PatternProperties);
ui->actionPattern_properties->setEnabled(false);
@@ -1292,9 +1292,9 @@ void MainWindow::Open()
//---------------------------------------------------------------------------------------------------------------------
/**
- * @brief Options config dialog.
+ * @brief Preferences config dialog.
*/